module Guard
  class Unity
    class Notifier
      class CLI

        require 'formatador'

        attr_accessor :formatador

        SEPARATOR = '-'*100

        def initialize(options={})
          @formatador = options[:formatador] || Formatador.new
        end

        def notify(results={})
          cases   = results[:test_cases] || []
          table   = []
          errors  = []

          cases.each do |test_case|
            table   << _row(test_case)
            errors  << _error(test_case) if test_case[:failed]
          end
          _display_results results
          _display_table table
          _display_errors errors
        end

        private

        def _display_results(results)
          table = [{
            'Tests' => results[:tests],
            'Failures' => results[:failures],
            'Errors' => results[:errors],
            'Ignored' => results[:ignored],
            'Skipped' => results[:skipped],
            'Inconclusive' => results[:inconclusive],
            'Invalid' => results[:invalid],
            'Not Run' => results[:not_run]
          }]
          formatador.display_table table, ['Tests', 'Failures', 'Errors', 'Ignored', 'Skipped', 'Inconclusive', 'Invalid', 'Not Run']
          formatador.display_line
        end

        def _display_table(table)
          formatador.display_table table
        end

        def _display_errors(errors)
          formatador.display_line
          formatador.display_line SEPARATOR
          formatador.display_line "| [red]Failures[/]"
          formatador.display_line SEPARATOR
          count = 1
          errors.each do |error|
            formatador.display_line
            formatador.display_line "#{count}: #{error[:name]}:\n"
            formatador.display_line "[red]#{error[:message]}[/]\n" unless error[:message] == ""
            formatador.display_line "[red]#{error[:stack]}[/]\n" unless error[:stack] == ""
            formatador.display_line SEPARATOR
            count = count + 1
          end
        end

        def _row(test_case)
          success = (test_case[:failed]) ? '[red]Failed[/]' : '[green]Success[/]'
          {name: test_case[:name], success: success}
        end

        def _error(test_case)
          {name: test_case[:name], message: test_case[:message], stack: test_case[:stack]}
        end

      end
    end
  end
end