module Guard
  class Unity
    class Runner

      require 'guard/unity/parser'
      require 'guard/unity/notifier'

      attr_accessor :options, :parser, :notifier

      def initialize(options = {})
        @options  = options
        @parser   = options[:parser]    || Guard::Unity::Parser.new(options)
        @notifier = options[:notifier]  || Guard::Unity::Notifier.new
      end

      def run
        _run
      end

      private

      def _run
        UI.info 'Guard::Unity - Starting Tests. Results will be displayed when finished testing.'
        output = _execute_command _command
        notifier.notify(parser.parse) if $?.success?
        output
      end

      def _command
        cmd = []

        cmd << options[:unity]
        cmd << '-projectPath ' + options[:project_path]
        cmd << '-batchmode -executeMethod UnityTest.UnitTestView.RunAllTestsBatch'

        cmd.join ' '
      end

      def _execute_command(command)
        %x{#{command}}
      end

    end
  end
end
